if [ -z ${CONDA_BUILD+x} ]; then
    source /var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_a1mr1x30d4/croot/hatch-jupyter-builder_1683742834729/work/build_env_setup.sh
fi
/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_a1mr1x30d4/croot/hatch-jupyter-builder_1683742834729/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pl/bin/python -m pip install --no-deps --no-build-isolation . -vv